"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TipManager = void 0;
const noomitip_en_1 = require("../locales/noomitip_en");
const noomitip_zh_1 = require("../locales/noomitip_zh");
const application_1 = require("./application");
const util_1 = require("./util");
/**
 * 获取体胖信息
 */
class TipManager {
    /**
     * 获取消息
     * @param type -    类型
     * @param code -    错误码
     * @param params -  参数
     * @returns         提示信息
     */
    static get(type, code, ...params) {
        let msg;
        switch (application_1.App.language) {
            case 'en':
                msg = noomitip_en_1.NoomiTip_en;
                break;
            default:
                msg = noomitip_zh_1.NoomiTip_zh;
        }
        if (params.length > 0) {
            return util_1.Util.compileString(msg[type][code], ...params);
        }
        return msg[type][code];
    }
    /**
     * 获取提示信息
     * @param code -    提示码
     * @param params -  参数
     * @returns         提示信息
     */
    static getTip(code, ...params) {
        return this.get('tip', code, ...params);
    }
    /**
     * 获取异常信息
     * @param code -    提示码
     * @param params -  参数
     * @returns         异常信息
     */
    static getError(code, ...params) {
        return this.get('error', code, ...params) || this.get('error', '0000');
    }
    /**
     * 获取模型校验或验证信息
     * @param code -    提示码
     * @param params-   参数
     * @returns         信息
     */
    static getModel(code, ...params) {
        return this.get('model', code, ...params);
    }
}
exports.TipManager = TipManager;
//# sourceMappingURL=tipmanager.js.map