"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PostTextHandler = void 0;
const application_1 = require("../tools/application");
/**
 * 针对post不同mime进行处理
 */
class PostTextHandler {
    /**
     * 初始化mimeType和buf
     * @param contentTypeObj - contentType对象
     */
    constructor(contentTypeObj) {
        this.mimeType = contentTypeObj;
        this.buf = Buffer.from('');
    }
    /**
     * 处理buf
     * @param buf -  新缓冲区
     */
    handleBuf(buf) {
        this.buf = Buffer.concat([this.buf, buf]);
    }
    /**
     * 获取result
     * @returns     文本串/json对象
     */
    getResult() {
        if (!this.buf || this.buf.length === 0) {
            return;
        }
        const charset = this.mimeType.charset || 'utf8';
        let bufStr = this.buf.toString(charset);
        if (this.mimeType.type === 'application/x-www-form-urlencoded') { //urlencode
            bufStr = decodeURIComponent(bufStr);
            return application_1.App.qs.parse(bufStr);
        }
        if (this.mimeType.type === 'application/json') { // json
            return JSON.parse(bufStr);
        }
        return { data: bufStr };
    }
}
exports.PostTextHandler = PostTextHandler;
//# sourceMappingURL=posttexthandler.js.map