import { HttpRequest } from "../../web/httprequest";
import { HttpResponse } from "../../web/httpresponse";
/**
 * 路由基类
 * @remarks
 * 可自动为路由类生成model(存放http请求参数的对象)，自带request和response对象，
 * 建议所有路由继承此基类
 */
export declare class BaseRoute {
    /**
     * 模型类
     */
    __modelClass: unknown;
    /**
     * 数据对象
     */
    model: any;
    /**
     * request对象
     */
    request: HttpRequest;
    /**
     * response对象
     */
    response: HttpResponse;
    /**
     * model设置
     * @remarks
     * 操作包含：
     *
     * 1. 数据类型转换
     *
     * 2. 数据校验
     *
     * 如果类型转换或数据校验未通过，抛出异常
     * @param data -        数据对象(由浏览器/客户端传入的数据参数)
     * @param methodName -  路由方法名
     * @throws              抛出数据转换或校验异常对象信息
     */
    setModel(data: object, methodName?: string): void;
    /**
     * 设置request对象
     * @param req -   request对象
     */
    setRequest(req: HttpRequest): void;
    /**
     * 设置response对象
     * @param res -   response对象
     */
    setResponse(res: HttpResponse): void;
}
